@@ -5,8 +5,6 @@ rm *.rst
 rm *.bak
 rm winff.exe
 rm winff
-rm *.lrt
-rm *.lrs
 rm *.or
 rm *.compiled
 rm backup/*
